@@ -3,6 +3,38 @@ Public API for extending Abrek
 """
 from abc import abstractmethod, abstractproperty
 
+class ITestProvider(object):
+    """
+    Abrek test provider.
+
+    Abstract source of abrek tests.
+    """
+
+    @abstractmethod
+    def __init__(self, config):
+        """
+        Initialize test provider with the specified configuration object. The
+        configuration object is obtained from the abrek providers registry.
+        """
+
+    @abstractmethod
+    def __iter__(self):
+        """
+        Iterates over instances of ITest exposed by this provider
+        """
+
+    @abstractmethod
+    def __getitem__(self, test_name):
+        """
+        Return an instance of ITest with the specified name
+        """
+
+    @abstractproperty
+    def description(self):
+        """
+        The description string used by abrek list-tests
+        """
+
 
 class ITest(object):
     """
